transform.performing_lab()
Performing Lab
Usage
To be used within a .with_columns statement to produce new columns in a dataframe
Examples
Defaults to PHL. This needs to be a reference code for WDRS facility WA State PHL (Public Health Laboratories) which is 81594
import polars as pl
import polars.selectors as cs
import wadoh_subtyping.transform as tf
import wadoh_raccoon.utils.helpers as helpers
# Main DataFrame (df)
df = pl.DataFrame({
"FIRST_NAME": ["john", "a-lice", "BOb"]
})
df = (
df
.with_columns(
PERFORMING_LAB_ENTIRE_REPORT = tf.performing_lab()
)
)
helpers.gt_style(df_inp=df)
| 0 |
john |
81596 |
| 1 |
a-lice |
81596 |
| 2 |
BOb |
81596 |